==> pipewire-docs-1%3A0.3.32-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/structspa__video__info__raw.js <==
var structspa__video__info__raw =
[
    [ "chroma_site", "structspa__video__info__raw.html#af85622f27e56fe5ce8675d2523d93884", null ],
    [ "color_matrix", "structspa__video__info__raw.html#ad56c11bdb72352e9407e39535b55deed", null ],
    [ "color_primaries", "structspa__video__info__raw.html#a0add074733e5354cfea4f633b23feeec", null ],
    [ "color_range", "structspa__video__info__raw.html#a37a68aa68e7ce91c4d8da20437664b19", null ],
    [ "format", "structspa__video__info__raw.html#ad417a8eb76373dd414e0f76662e2ead6", null ],
    [ "framerate", "structspa__video__info__raw.html#a73891e491000758f521c9b701f8cfeaf", null ],
    [ "interlace_mode", "structspa__video__info__raw.html#a25b3f0682ca30d079c005868650c23ed", null ],
    [ "max_framerate", "structspa__video__info__raw.html#af59a82989f29004917bb4f62b003addb", null ],
    [ "modifier", "structspa__video__info__raw.html#acc3883d98af70282cb7536274e0edd74", null ],
    [ "multiview_flags", "structspa__video__info__raw.html#a99a7b7e3ccd534510cb33036028edd7e", null ],
    [ "multiview_mode", "structspa__video__info__raw.html#a48a1b5480465ffdcee2dfa9e95ed47fb", null ],
    [ "pixel_aspect_ratio", "structspa__video__info__raw.html#a3bedf6a844bdca773ab5840615f87d73", null ],
    [ "size", "structspa__video__info__raw.html#a371bed1caf6cc1ffbbdd6bae58883d59", null ],
    [ "transfer_function", "structspa__video__info__raw.html#a1b34707c39ebadbae7550a997a29bf5f", null ],
    [ "views", "structspa__video__info__raw.html#a4f6cf0e98b78c96384b6ffb372e2d9db", null ]
];

==> pipewire-docs-1%3A0.3.63-3-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/structspa__video__info__raw.js <==
var structspa__video__info__raw =
[
    [ "format", "structspa__video__info__raw.html#ad417a8eb76373dd414e0f76662e2ead6", null ],
    [ "modifier", "structspa__video__info__raw.html#acc3883d98af70282cb7536274e0edd74", null ],
    [ "size", "structspa__video__info__raw.html#a371bed1caf6cc1ffbbdd6bae58883d59", null ],
    [ "framerate", "structspa__video__info__raw.html#a73891e491000758f521c9b701f8cfeaf", null ],
    [ "max_framerate", "structspa__video__info__raw.html#af59a82989f29004917bb4f62b003addb", null ],
    [ "views", "structspa__video__info__raw.html#a4f6cf0e98b78c96384b6ffb372e2d9db", null ],
    [ "interlace_mode", "structspa__video__info__raw.html#a25b3f0682ca30d079c005868650c23ed", null ],
    [ "pixel_aspect_ratio", "structspa__video__info__raw.html#a3bedf6a844bdca773ab5840615f87d73", null ],
    [ "multiview_mode", "structspa__video__info__raw.html#a48a1b5480465ffdcee2dfa9e95ed47fb", null ],
    [ "multiview_flags", "structspa__video__info__raw.html#a99a7b7e3ccd534510cb33036028edd7e", null ],
    [ "chroma_site", "structspa__video__info__raw.html#af85622f27e56fe5ce8675d2523d93884", null ],
    [ "color_range", "structspa__video__info__raw.html#a37a68aa68e7ce91c4d8da20437664b19", null ],
    [ "color_matrix", "structspa__video__info__raw.html#ad56c11bdb72352e9407e39535b55deed", null ],
    [ "transfer_function", "structspa__video__info__raw.html#a1b34707c39ebadbae7550a997a29bf5f", null ],
    [ "color_primaries", "structspa__video__info__raw.html#a0add074733e5354cfea4f633b23feeec", null ]
];
